@@ -1,5 +1,7 @@
-from ._base import IsInstanceOf
+from ._base import AnyThing, IsInstance
 from ._datetime import IsDatetime, IsNow
+from ._dict import IsDict, IsPartialDict, IsStrictDict
+from ._list_tuple import HasLen, IsList, IsListOrTuple, IsTuple
 from ._numeric import (
     IsApprox,
     IsFloat,
@@ -8,26 +10,32 @@ from ._numeric import (
     IsNegativeFloat,
     IsNegativeInt,
     IsNonNegative,
-    IsNonNegativeFloat,
-    IsNonNegativeInt,
     IsNonPositive,
-    IsNonPositiveFloat,
-    IsNonPositiveInt,
     IsNumber,
     IsNumeric,
     IsPositive,
     IsPositiveFloat,
     IsPositiveInt,
 )
-from ._other import IsUUID
+from ._other import FunctionCheck, IsJson, IsUUID
 from ._strings import IsAnyStr, IsBytes, IsStr
 
 __all__ = (
     # base
-    'IsInstanceOf',
+    'AnyThing',
+    'IsInstance',
     # datetime
     'IsDatetime',
     'IsNow',
+    # dict
+    'IsDict',
+    'IsPartialDict',
+    'IsStrictDict',
+    # list or tuple
+    'HasLen',
+    'IsList',
+    'IsTuple',
+    'IsListOrTuple',
     # numeric
     'IsNumeric',
     'IsApprox',
@@ -39,14 +47,12 @@ __all__ = (
     'IsInt',
     'IsPositiveInt',
     'IsNegativeInt',
-    'IsNonPositiveInt',
-    'IsNonNegativeInt',
     'IsFloat',
     'IsPositiveFloat',
     'IsNegativeFloat',
-    'IsNonPositiveFloat',
-    'IsNonNegativeFloat',
     # other
+    'FunctionCheck',
+    'IsJson',
     'IsUUID',
     # strings
     'IsStr',
@@ -56,4 +62,4 @@ __all__ = (
     '__version__',
 )
 
-__version__ = '0.0.2'
+__version__ = '0.0.3'
