@@ -1,5 +1,5 @@
 from abc import ABCMeta
-from typing import Any, Dict, Generic, Iterable, Optional, Tuple, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, Generic, Iterable, Optional, Tuple, TypeVar, Union
 
 try:
     from typing import Protocol
@@ -9,34 +9,37 @@ except ImportError:
 
 from ._utils import Omit
 
-__all__ = 'DirtyEquals', 'IsInstanceOf'
+if TYPE_CHECKING:
+    from typing import TypeAlias
+
+__all__ = 'DirtyEquals', 'IsInstance', 'AnyThing'
 
 
 class DirtyEqualsMeta(ABCMeta):
-    def _get_instance(self) -> 'DirtyEquals[Any]':
-        try:
-            return self()
-        except TypeError as e:
-            raise TypeError(f'{self.__name__} cannot be used without initialising') from e
-
     def __eq__(self, other: Any) -> bool:
-        # this is required as fancy things happen when creating generics which include equals checks
+        # this is required as fancy things happen when creating generics which include equals checks, without it
+        # we get some recursive errors
         if self is DirtyEquals or other is Generic or other is Protocol:
             return False
         else:
-            return self._get_instance() == other
+            try:
+                return self() == other
+            except TypeError:
+                # we don't want to raise a type error here since somewhere deep in pytest it does something like
+                # type(a) == type(b), if we raised TypeError we would upset the pytest error message
+                return False
 
-    def __or__(self, other: Any) -> 'DirtyOr':
-        return self._get_instance() | other
+    def __or__(self, other: Any) -> 'DirtyOr':  # type: ignore[override]
+        return DirtyOr(self, other)
 
     def __and__(self, other: Any) -> 'DirtyAnd':
-        return self._get_instance() & other
+        return DirtyAnd(self, other)
 
     def __invert__(self) -> 'DirtyNot':
-        return ~self._get_instance()
+        return DirtyNot(self)
 
     def __repr__(self) -> str:
-        return f'{self.__name__}()'
+        return self.__name__
 
 
 T = TypeVar('T')
@@ -70,6 +73,16 @@ class DirtyEquals(Generic[T], metaclass=DirtyEqualsMeta):
 
         return self._was_equal
 
+    def __ne__(self, other: Any) -> bool:
+        """
+        We don't set _was_equal to avoid strange errors in pytest
+        """
+        self._other = other
+        try:
+            return not self.equals(other)
+        except (TypeError, ValueError):
+            return True
+
     def __or__(self, other: Any) -> 'DirtyOr':
         return DirtyOr(self, other)
 
@@ -93,8 +106,11 @@ class DirtyEquals(Generic[T], metaclass=DirtyEqualsMeta):
             return self._repr_ne()
 
 
+InstanceOrType: 'TypeAlias' = 'Union[DirtyEquals[Any], DirtyEqualsMeta]'
+
+
 class DirtyOr(DirtyEquals[Any]):
-    def __init__(self, a: DirtyEquals[Any], b: DirtyEquals[Any], *extra: DirtyEquals[Any]):
+    def __init__(self, a: 'InstanceOrType', b: 'InstanceOrType', *extra: 'InstanceOrType'):
         self.dirties = (a, b) + extra
         super().__init__()
 
@@ -102,11 +118,11 @@ class DirtyOr(DirtyEquals[Any]):
         return any(d == other for d in self.dirties)
 
     def _repr_ne(self) -> str:
-        return f'{self.__class__.__name__}({" | ".join(repr(d) for d in self.dirties)})'
+        return ' | '.join(_repr_ne(d) for d in self.dirties)
 
 
 class DirtyAnd(DirtyEquals[Any]):
-    def __init__(self, a: DirtyEquals[Any], b: DirtyEquals[Any], *extra: DirtyEquals[Any]):
+    def __init__(self, a: InstanceOrType, b: InstanceOrType, *extra: InstanceOrType):
         self.dirties = (a, b) + extra
         super().__init__()
 
@@ -114,27 +130,37 @@ class DirtyAnd(DirtyEquals[Any]):
         return all(d == other for d in self.dirties)
 
     def _repr_ne(self) -> str:
-        return f'{self.__class__.__name__}({" & ".join(repr(d) for d in self.dirties)})'
+        return ' & '.join(_repr_ne(d) for d in self.dirties)
 
 
 class DirtyNot(DirtyEquals[Any]):
-    def __init__(self, subject: DirtyEquals[Any]):
+    def __init__(self, subject: InstanceOrType):
         self.subject = subject
         super().__init__()
 
     def equals(self, other: Any) -> bool:
         return self.subject != other
 
+    def _repr_ne(self) -> str:
+        return f'~{_repr_ne(self.subject)}'
+
+
+def _repr_ne(v: InstanceOrType) -> str:
+    if isinstance(v, DirtyEqualsMeta):
+        return repr(v)
+    else:
+        return v._repr_ne()
+
 
 ExpectedType = TypeVar('ExpectedType', bound=Union[type, Tuple[Union[type, Tuple[Any, ...]], ...]])
 
 
-class IsInstanceOfMeta(DirtyEqualsMeta):
-    def __getitem__(self, item: ExpectedType) -> 'IsInstanceOf[ExpectedType]':
-        return IsInstanceOf(item)
+class IsInstanceMeta(DirtyEqualsMeta):
+    def __getitem__(self, item: ExpectedType) -> 'IsInstance[ExpectedType]':
+        return IsInstance(item)
 
 
-class IsInstanceOf(DirtyEquals[ExpectedType], metaclass=IsInstanceOfMeta):
+class IsInstance(DirtyEquals[ExpectedType], metaclass=IsInstanceMeta):
     def __init__(self, expected_type: ExpectedType, only_direct_instance: bool = False):
         self.expected_type = expected_type
         self.only_direct_instance = only_direct_instance
@@ -145,3 +171,8 @@ class IsInstanceOf(DirtyEquals[ExpectedType], metaclass=IsInstanceOfMeta):
             return type(other) == self.expected_type
         else:
             return isinstance(other, self.expected_type)
+
+
+class AnyThing(DirtyEquals[Any]):
+    def equals(self, other: Any) -> bool:
+        return True
