@@ -5,6 +5,7 @@ from typing import Any, Optional, Tuple, Type, TypeVar, Union
 from ._base import DirtyEquals
 
 __all__ = (
+    'IsApprox',
     'IsNumeric',
     'IsNumber',
     'IsPositive',
@@ -14,23 +15,19 @@ __all__ = (
     'IsInt',
     'IsPositiveInt',
     'IsNegativeInt',
-    'IsNonPositiveInt',
-    'IsNonNegativeInt',
     'IsFloat',
     'IsPositiveFloat',
     'IsNegativeFloat',
-    'IsNonPositiveFloat',
-    'IsNonNegativeFloat',
 )
 
 from ._utils import Omit
 
-AnyNumber = Union[int, float, complex, Decimal]
-N = TypeVar('N', int, float, complex, Decimal, date, datetime, AnyNumber)
+AnyNumber = Union[int, float, Decimal]
+N = TypeVar('N', int, float, Decimal, date, datetime, AnyNumber)
 
 
 class IsNumeric(DirtyEquals[N]):
-    types: Union[Type[N], Tuple[type, ...]] = (int, float, complex, Decimal, date, datetime)
+    types: Union[Type[N], Tuple[type, ...]] = (int, float, Decimal, date, datetime)
 
     def __init__(
         self,
@@ -43,7 +40,7 @@ class IsNumeric(DirtyEquals[N]):
         le: Optional[N] = None,
     ):
         self.approx: Optional[N] = approx
-        self.delta: Any = delta
+        self.delta: Optional[N] = delta
         if self.approx is not None and (gt, lt, ge, le) != (None, None, None, None):
             raise TypeError('"approx" cannot be combined with "gt", "lt", "ge", or "le"')
         self.gt: Optional[N] = gt
@@ -52,12 +49,12 @@ class IsNumeric(DirtyEquals[N]):
         self.le: Optional[N] = le
         self.has_bounds_checks = not all(f is None for f in (approx, delta, gt, lt, ge, le))
         kwargs = {
-            'approx': approx or Omit,
-            'delta': delta or Omit,
-            'gt': gt or Omit,
-            'lt': lt or Omit,
-            'ge': ge or Omit,
-            'le': le or Omit,
+            'approx': Omit if approx is None else approx,
+            'delta': Omit if delta is None else delta,
+            'gt': Omit if gt is None else gt,
+            'lt': Omit if lt is None else lt,
+            'ge': Omit if ge is None else ge,
+            'le': Omit if le is None else le,
         }
         super().__init__(**kwargs)
 
@@ -77,33 +74,36 @@ class IsNumeric(DirtyEquals[N]):
         else:
             return True
 
-    def bounds_checks(self, other: Any) -> bool:
+    def bounds_checks(self, other: N) -> bool:
         if self.approx is not None:
             if self.delta is None:
-                if isinstance(other, datetime):
-                    delta = timedelta(seconds=1)
+                if isinstance(other, date):
+                    delta: Any = timedelta(seconds=1)
                 else:
                     delta = other / 100
             else:
                 delta = self.delta
-            return abs(self.approx - other) <= delta
-        elif self.gt is not None and other <= self.gt:
+            return self.approx_equals(other, delta)
+        elif self.gt is not None and not other > self.gt:
             return False
-        elif self.lt is not None and other >= self.lt:
+        elif self.lt is not None and not other < self.lt:
             return False
-        elif self.ge is not None and other < self.ge:
+        elif self.ge is not None and not other >= self.ge:
             return False
-        elif self.le is not None and other > self.le:
+        elif self.le is not None and not other <= self.le:
             return False
         else:
             return True
 
+    def approx_equals(self, other: Any, delta: Any) -> bool:
+        return abs(self.approx - other) <= delta
+
 
 class IsNumber(IsNumeric[AnyNumber]):
-    types = int, float, complex, Decimal
+    types = int, float, Decimal
 
 
-Num = TypeVar('Num', int, float, complex, Decimal)
+Num = TypeVar('Num', int, float, Decimal)
 
 
 class IsApprox(IsNumber):
@@ -114,21 +114,25 @@ class IsApprox(IsNumber):
 class IsPositive(IsNumber):
     def __init__(self) -> None:
         super().__init__(gt=0)
+        self._repr_kwargs = {}
 
 
 class IsNegative(IsNumber):
     def __init__(self) -> None:
         super().__init__(lt=0)
+        self._repr_kwargs = {}
 
 
 class IsNonPositive(IsNumber):
     def __init__(self) -> None:
         super().__init__(le=0)
+        self._repr_kwargs = {}
 
 
 class IsNonNegative(IsNumber):
     def __init__(self) -> None:
         super().__init__(ge=0)
+        self._repr_kwargs = {}
 
 
 class IsInt(IsNumeric[int]):
@@ -138,21 +142,13 @@ class IsInt(IsNumeric[int]):
 class IsPositiveInt(IsInt):
     def __init__(self) -> None:
         super().__init__(gt=0)
+        self._repr_kwargs = {}
 
 
 class IsNegativeInt(IsInt):
     def __init__(self) -> None:
         super().__init__(lt=0)
-
-
-class IsNonPositiveInt(IsInt):
-    def __init__(self) -> None:
-        super().__init__(le=0)
-
-
-class IsNonNegativeInt(IsInt):
-    def __init__(self) -> None:
-        super().__init__(ge=0)
+        self._repr_kwargs = {}
 
 
 class IsFloat(IsNumeric[float]):
@@ -162,18 +158,10 @@ class IsFloat(IsNumeric[float]):
 class IsPositiveFloat(IsFloat):
     def __init__(self) -> None:
         super().__init__(gt=0)
+        self._repr_kwargs = {}
 
 
 class IsNegativeFloat(IsFloat):
     def __init__(self) -> None:
         super().__init__(lt=0)
-
-
-class IsNonPositiveFloat(IsFloat):
-    def __init__(self) -> None:
-        super().__init__(le=0)
-
-
-class IsNonNegativeFloat(IsFloat):
-    def __init__(self) -> None:
-        super().__init__(ge=0)
+        self._repr_kwargs = {}
